@@ -454,7 +454,7 @@ def generate_excel_file(run_id, orgId, report_gen_start_time, report_gen_complet
     if storage_name == 's3':
         excel_url = upload_excel_s3(filepath, BUCKET_NAME, excel_file_location)
     elif storage_name == 'ceph':
-        excel_url = upload_excel_ceph(filepath, BUCKET_NAME excel_file_location)
+        excel_url = upload_excel_ceph(filepath, BUCKET_NAME, excel_file_location)
     else:
         logger.info("No storages are found")
     return excel_url
